==> lms-1.1.2b.tar.gz: lms/modules/tarifflist.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tarifflist.php,v 1.17 2003/08/24 13:12:54 lukasz Exp $
 */

$layout[pagetitle]="Lista taryf";

$tarifflist = $LMS->GetTariffList();

$listdata[total] = $tarifflist[total];
$listdata[totalincome] = $tarifflist[totalincome];
$listdata[totalusers] = $tarifflist[totalusers];

unset($tarifflist[total],$tarifflist[totalincome],$tarifflist[totalusers]);

$SMARTY->assign("tarifflist",$tarifflist);
$SMARTY->assign("listdata",$listdata);
$SMARTY->assign("layout",$layout);
$SMARTY->display("tarifflist.html");
/*
 * $Log: tarifflist.php,v $
 * Revision 1.17  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.16  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>

==> lms-1.1.5.tar.gz: lms/modules/tarifflist.php <==
<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tarifflist.php,v 1.18 2003/09/09 01:22:28 lukasz Exp $
 */

$layout[pagetitle]="Lista taryf";

$tarifflist = $LMS->GetTariffList();

$listdata[total] = $tarifflist[total];
$listdata[totalincome] = $tarifflist[totalincome];
$listdata[totalusers] = $tarifflist[totalusers];
$listdata[totalcount] = $tarifflist[totalcount];

unset($tarifflist[total],$tarifflist[totalincome],$tarifflist[totalusers],$tarifflist[totalcount]);

$SMARTY->assign("tarifflist",$tarifflist);
$SMARTY->assign("listdata",$listdata);
$SMARTY->assign("layout",$layout);
$SMARTY->display("tarifflist.html");
/*
 * $Log: tarifflist.php,v $
 * Revision 1.18  2003/09/09 01:22:28  lukasz
 * - nowe finanse
 * - kosmetyka
 * - bugfixy
 * - i inne rzeczy o ktrych aktualnie nie pamitam
 *
 * Revision 1.17  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.16  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>
